==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/ka_GE.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "გაზიარება",
    "External Storage" : "ექსტერნალ საცავი",
    "Cron" : "Cron–ი",
    "Log" : "ლოგი",
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Language changed" : "ენა შეცვლილია",
    "Invalid request" : "არასწორი მოთხოვნა",
    "Admins can't remove themself from the admin group" : "ადმინისტრატორებს არ შეუძლიათ საკუთარი თავის წაშლა ადმინ ჯგუფიდან",
    "Unable to add user to group %s" : "მომხმარებლის დამატება ვერ მოხეხდა ჯგუფში %s",
    "Unable to remove user from group %s" : "მომხმარებლის წაშლა ვერ მოხეხდა ჯგუფიდან %s",
    "Couldn't update app." : "ვერ მოხერხდა აპლიკაციის განახლება.",
    "Email sent" : "იმეილი გაიგზავნა",
    "Email saved" : "იმეილი შენახულია",
    "All" : "ყველა",
    "Please wait...." : "დაიცადეთ....",
    "Disable" : "გამორთვა",
    "Enable" : "ჩართვა",
    "Updating...." : "მიმდინარეობს განახლება....",
    "Error while updating app" : "შეცდომა აპლიკაციის განახლების დროს",
    "Updated" : "განახლებულია",
    "Delete" : "წაშლა",
    "Groups" : "ჯგუფები",
    "undo" : "დაბრუნება",
    "never" : "არასდროს",
    "add group" : "ჯგუფის დამატება",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "Error creating user" : "შეცდომა მომხმარებლის შექმნისას",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "__language_name__" : "__language_name__",
    "SSL root certificates" : "SSL root სერთიფიკატები",
    "None" : "არა",
    "Login" : "ლოგინი",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP მოდული 'fileinfo' არ არსებობს. ჩვენ გირჩევთ რომ აუცილებლად ჩართოთ ეს მოდული, რომ მიიღოთ კარგი შედეგები mime-type–ს აღმოჩენისას.",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Allow resharing" : "გადაზიარების დაშვება",
    "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
    "Encryption" : "ენკრიპცია",
    "Server address" : "სერვერის მისამართი",
    "Port" : "პორტი",
    "Credentials" : "იუზერ/პაროლი",
    "Log level" : "ლოგირების დონე",
    "More" : "უფრო მეტი",
    "Less" : "უფრო ნაკლები",
    "Version" : "ვერსია",
    "by" : "მიერ",
    "Forum" : "ფორუმი",
    "Get the apps to sync your files" : "აპლიკაცია ფაილების სინქრონიზაციისთვის",
    "Show First Run Wizard again" : "მაჩვენე თავიდან გაშვებული ვიზარდი",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "თქვენ გამოყენებული გაქვთ <strong>%s</strong> –ი –<strong>%s<strong>–დან",
    "Password" : "პაროლი",
    "Unable to change your password" : "თქვენი პაროლი არ შეიცვალა",
    "Current password" : "მიმდინარე პაროლი",
    "New password" : "ახალი პაროლი",
    "Change password" : "პაროლის შეცვლა",
    "Email" : "იმეილი",
    "Your email address" : "თქვენი იმეილ მისამართი",
    "Cancel" : "უარყოფა",
    "Language" : "ენა",
    "Help translate" : "თარგმნის დახმარება",
    "Username" : "მომხმარებლის სახელი",
    "Create" : "შექმნა",
    "Default Quota" : "საწყისი ქვოტა",
    "Unlimited" : "ულიმიტო",
    "Other" : "სხვა",
    "Quota" : "ქვოტა",
    "set new password" : "დააყენეთ ახალი პაროლი",
    "Default" : "საწყისი პარამეტრები"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/ka_GE.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Email sent" : "იმეილი გაიგზავნა",
    "Email saved" : "იმეილი შენახულია",
    "Sharing" : "გაზიარება",
    "External Storage" : "ექსტერნალ საცავი",
    "Cron" : "Cron–ი",
    "Log" : "ლოგი",
    "Language changed" : "ენა შეცვლილია",
    "Invalid request" : "არასწორი მოთხოვნა",
    "Admins can't remove themself from the admin group" : "ადმინისტრატორებს არ შეუძლიათ საკუთარი თავის წაშლა ადმინ ჯგუფიდან",
    "Unable to add user to group %s" : "მომხმარებლის დამატება ვერ მოხეხდა ჯგუფში %s",
    "Unable to remove user from group %s" : "მომხმარებლის წაშლა ვერ მოხეხდა ჯგუფიდან %s",
    "Couldn't update app." : "ვერ მოხერხდა აპლიკაციის განახლება.",
    "All" : "ყველა",
    "Please wait...." : "დაიცადეთ....",
    "Disable" : "გამორთვა",
    "Enable" : "ჩართვა",
    "Updating...." : "მიმდინარეობს განახლება....",
    "Error while updating app" : "შეცდომა აპლიკაციის განახლების დროს",
    "Updated" : "განახლებულია",
    "Delete" : "წაშლა",
    "Groups" : "ჯგუფები",
    "undo" : "დაბრუნება",
    "never" : "არასდროს",
    "add group" : "ჯგუფის დამატება",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "__language_name__" : "__language_name__",
    "Unlimited" : "ულიმიტო",
    "None" : "არა",
    "Login" : "ლოგინი",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP მოდული 'fileinfo' არ არსებობს. ჩვენ გირჩევთ რომ აუცილებლად ჩართოთ ეს მოდული, რომ მიიღოთ კარგი შედეგები mime-type–ს აღმოჩენისას.",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Allow resharing" : "გადაზიარების დაშვება",
    "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
    "Encryption" : "ენკრიპცია",
    "Server address" : "სერვერის მისამართი",
    "Port" : "პორტი",
    "Credentials" : "იუზერ/პაროლი",
    "More" : "უფრო მეტი",
    "Less" : "უფრო ნაკლები",
    "Version" : "ვერსია",
    "Forum" : "ფორუმი",
    "Cancel" : "უარყოფა",
    "Email" : "იმეილი",
    "Your email address" : "თქვენი იმეილ მისამართი",
    "Password" : "პაროლი",
    "Unable to change your password" : "თქვენი პაროლი არ შეიცვალა",
    "Current password" : "მიმდინარე პაროლი",
    "New password" : "ახალი პაროლი",
    "Change password" : "პაროლის შეცვლა",
    "Language" : "ენა",
    "Help translate" : "თარგმნის დახმარება",
    "Name" : "სახელი",
    "Username" : "მომხმარებლის სახელი",
    "Get the apps to sync your files" : "აპლიკაცია ფაილების სინქრონიზაციისთვის",
    "Show First Run Wizard again" : "მაჩვენე თავიდან გაშვებული ვიზარდი",
    "Create" : "შექმნა",
    "Default Quota" : "საწყისი ქვოტა",
    "Other" : "სხვა",
    "Quota" : "ქვოტა",
    "set new password" : "დააყენეთ ახალი პაროლი",
    "Default" : "საწყისი პარამეტრები"
},
"nplurals=1; plural=0;");
